%This function returns the expected annual cost of satisfying the whole
%annual demand (in Euros)


%Inputs: existing thermal capacity 'k' and oil price 'oilp'

% The program uses historical average monthly thermal output as demand and
% adds a normally distributed shock, with standard deviations estimated
% separately for each month

% Unit of input k is MW

function Y = AnnualCost(k,oilp)

% Estimated demand data: Monthly average thermal demands in GWh
% Note: one month is here 4 weeks, so there are 13 'months' in a year
Dthermal = 1.0e+004 *[

    1.7312;
    1.7219;
    1.6987;
    1.5524;
    1.2905;
    1.1291;
    1.0646;
    1.0341;
    1.1618;
    1.3023;
    1.5029;
    1.6480;
    1.6883];


% calculate the monthly output of existing capacity (in GWh/month)
kout=(k*28*24)/1000; %28 days * 24 hours in month (we have 13 "months" in a year, each lasting 28 days)

% standard deviations of demand shock for each month (in GWh/month)
sigma=[
1793.887609
1488.891349
1724.802631
2120.030658
2159.49847
2059.897288
2060.876501
2175.181979
1787.44249
1265.978929
1680.445962
1949.800284
1960.079672
];



noisestep=0.1; %grid step size for integrating over demand shocks
gridpoints=101;
noisegridbase=[-noisestep*(gridpoints-1)/2:noisestep:noisestep*(gridpoints-1)/2];
noisedens=(1/2)*(erf((noisegridbase+(noisestep/2))./sqrt(2))-erf((noisegridbase-(noisestep/2))./sqrt(2))); %density function for integrating over demand shocks


% Change units into MWh/week
kout = 1000*kout/4; 
Dthermal = 1000*Dthermal/4;

Y = zeros(13,1);
for t = 1:13
    costtemp=0;
    noisegrid=1000*(noisegridbase*sigma(t))./4;
    for noiseind=1:length(noisegrid),
        if kout<Dthermal(t)+noisegrid(noiseind),
            costtemp=costtemp+noisedens(noiseind)*Dthermal(t)*4*ElPrice(Dthermal(t)+noisegrid(noiseind),kout,t,oilp); %expected cost
        end
    end
    Y(t)=costtemp;
end
Y=sum(Y);
